<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author jk Lee
 * @author dongnak@gmail.com
 * @author Song Younghwan <purluno@gmail.com>
 * @author Seung-Chul Yoo <dryoo@live.com>
 * @author erial2@gmail.com
 * @author Myeongjin <aranet100@gmail.com>
 * @author Garam <rowain8@gmail.com>
 */
$lang['name']                  = '인기도 조사 (불러오는 데 시간이 걸릴 수 있습니다)';
$lang['submit']                = '자료 보내기';
$lang['autosubmit']            = '자료를 자동으로 한 달에 한 번씩 보내기';
$lang['submissionFailed']      = '다음과 같은 이유로 자료 보내기에 실패했습니다:';
$lang['submitDirectly']        = '아래의 양식에 맞춰 수동으로 작성된 자료를 보낼 수 있습니다.';
$lang['autosubmitError']       = '다음과 같은 이유로 자동 자료 보내기에 실패했습니다:';
$lang['lastSent']              = '자료를 보냈습니다';
